bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart
==========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. autoclass:: WrapToGaussianWishart

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~WrapToGaussianWishart.__init__
      ~WrapToGaussianWishart.add_plate_axis
      ~WrapToGaussianWishart.broadcasting_multiplier
      ~WrapToGaussianWishart.delete
      ~WrapToGaussianWishart.get_mask
      ~WrapToGaussianWishart.get_moments
      ~WrapToGaussianWishart.get_shape
      ~WrapToGaussianWishart.has_plotter
      ~WrapToGaussianWishart.lower_bound_contribution
      ~WrapToGaussianWishart.move_plates
      ~WrapToGaussianWishart.plot
      ~WrapToGaussianWishart.set_plotter
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
      :toctree: generated/
   
      ~WrapToGaussianWishart.plates
      ~WrapToGaussianWishart.plates_multiplier
   
   